@@ -64,3 +64,17 @@ class CustomResource(ResourceView):
 class DummyResource(ResourceView):
     def get(self, request, **resources):
         return True
+
+
+class BSONResource(ResourceView):
+
+    allowed_methods = 'GET', 'POST'
+
+    COUNTER = 1
+
+    def get(self, request, **resources):
+        return dict(counter=self.COUNTER)
+
+    def post(self, request, **resources):
+        self.COUNTER += request.data.get('counter', 0)
+        return dict(counter=self.COUNTER)
